#!/usr/bin/env python
#
# Windows.py
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA  02111-1307  USA


security_sys = ("afwcore.sys",
                "avgtpx86.sys",
                "avipbb.sys",
                "BkavAuto.sys",
                "catflt.sys",
                "cmderd.sys",
                "eamon.sys",
                "econceal.sys",
                "EstRtw.sys",
                "FortiRdr.sys",
                "FStopW.sys",
                "HookHelp.sys",
                "ImmunetProtect.sys",
                "kl1.sys",
                "klflt.sys",
                "klif.sys",
                "kneps.sys",
                "MpFilter.sys",
                "nvcw32mf.sys",
                "Parity.sys",
                "prl_boot.sys",
                "prl_fs.sys",
                "prl_kmdd.sys",
                "prl_memdev.sys",
                "prl_mouf.sys",
                "prl_pv32.sys",
                "prl_sound.sys",
                "prl_strg.sys",
                "prl_tg.sys",
                "prl_time.sys",
                "protreg.sys",
                "SophosBootDriver.sys",
                "SYMEVENT.SYS",
                "SysGuard.sys",
                "tmactmon.sys",
                "tmcomm.sys",
                "tmevtmgr.sys",
                "TMEBC32.sys",
                "tmeext.sys",
                "tmnciesc.sys",
                "tmtdi.sys",
                "vbengnt.sys",
                "vm3dmp.sys",
                "vmhgfs.sys",
                "vmusbmouse.sys",
                "vmmouse.sys",
                "vmhgfs.sys",
                "vmnet.sys",
                "vmusbmouse.sys",
                "vmx86.sys",
                "vmxnet.sys",
                "VBoxGuest.sys",
                "VBoxMouse.sys",
                "VBoxSF.sys",
                "VBoxVideo.sys",
                "WpsHelper.sys",
                "7z.exe",
                "a2cmd.exe",
                "acs.exe",
                "agb.exe",
                "ARKIT.EXE",
                "asOEHook.dll",
                "avcuf32.dll",
                "AYLaunch.exe",
                "AVG Secure Search_toolbar.dll",
                "avgdttbx.dll",
                "avp.exe",
                "avzkrnl.dll",
                "BdProvider.dll",
                "Bka.exe",
                "cfgconv.exe",
                "DoScan.exe",
                "drwebsp.dll",
                "egui.exe",
                "EMET.dll",
                "Fiddler.exe",
                "FortiClient.exe",
                "FPWin.exe",
                "fsesgui.exe",
                "fsgkiapi.dll",
                "FSLSP.DLL",
                "fshook32.dll",
                "klwtblc.dll",
                "instapi.dll",
                "ips.exe",
                "iTunesHelper.exe",
                "KVPopup.exe",
                "LangSel.exe",
                "McShield.dll",
                "mfc42.dll",
                "muis.dll",
                "mytilus3.dll",
                "mytilus3_worker.dll",
                "nse.exe",
                "nsphsvr.exe",
                "pctsGui.exe",
                "RavMonD.exe",
                "remote_eka_prague_loader.dll",
                "SavMain.exe",
                "setup_nativelook.exe",
                "shellex.dll",
                "shortcut.exe",
                "SOPHOS~1.DLL",
                "sqlvdi.dll",
                "SUPERAntiSpyware.exe",
                "TPAutoConnSvc.exe",
                "unGuardX.exe",
                "uninst.exe",
                "uiWinMgr.exe",
                "V3Main.exe",
                "Vrmonnt.exe",
                "winpers.exe",
                "WinRAR.exe",
                "wpsman.dll",
                "WZSHLSTB.DLL",
                "ZipSendB.dll")

win32_files = ("c:\\windows\\system32\\drivers\\etc\\hosts", )



#!/usr/bin/env python


class HTMLDocumentCompatibleInfo(object):
    """
    IHTMLDocumentCompatibleInfo provides information about the
    compatibity mode specified by the web page. If the web page
    specifies multiple compatibility modes, they can be retrieved
    using IHTMLDocumentCompatibleInfoCollection.

    http://msdn.microsoft.com/en-us/library/cc288659(v=vs.85).aspx

    There are no standards that apply here.
    """
    def __init__(self, useragent = '', version = ''):
        self._userAgent = useragent
        self._version   = version

    def getUserAgent(self):
        return self._userAgent

    def setUserAgent(self, useragent):
        self._userAgent = useragent

    userAgent = property(getUserAgent, setUserAgent)

    def getVersion(self):
        return self._version

    def setVersion(self, version):
        self._version = version

    version = property(getVersion, setVersion)



# BaoFeng Storm ActiveX Control SetAttributeValue() Buffer Overflow Vulnerability
# CVE-2009-1807

import logging

log = logging.getLogger("Thug")


def SetAttributeValue(self, arg0, arg1, arg2):
    if len(arg0) > 260:
        log.ThugLogging.log_exploit_event(self._window.url,
                                          "BaoFeng Storm ActiveX Control",
                                          "SetAttributeValue Buffer Overflow",
                                          cve = "CVE-2009-1807")

        log.ThugLogging.log_classifier("exploit", log.ThugLogging.url, "CVE-2009-1807", None)



#!/usr/bin/env python

import re

from .Node import Node


class DocumentType(Node):
    RE_DOCTYPE = re.compile("^DOCTYPE (\w+)", re.M + re.S)

    def __init__(self, doc, tag):
        self.tag = tag
        Node.__init__(self, doc)
        self.parse(tag)

    def parse(self, text):
        m = self.RE_DOCTYPE.match(text)

        self._name = m.group(1) if m else ""

    @property
    def name(self):
        return self._name

    @property
    def nodeName(self):
        return self._name

    @property
    def nodeType(self):
        return Node.DOCUMENT_TYPE_NODE

    @property
    def nodeValue(self):
        return None

    @property
    def entities(self):
        raise NotImplementedError()

    @property
    def notations(self):
        raise NotImplementedError()

    # Modified in DOM Level 2
    @property
    def ownerDocument(self):
        # FIXME
        return None

    # Introduced in DOM Level 2
    @property
    def publicId(self):
        pass

    # Introduced in DOM Level 2
    @property
    def systemId(self):
        pass

    # Introduced in DOM Level 2
    @property
    def internalSubset(self):
        pass



# Yahoo! Messenger 8.x CYTF ActiveX Control

import logging

log = logging.getLogger("Thug")


def GetFile(self, url, local, arg2, arg3, cmd):
    log.ThugLogging.add_behavior_warn('[Yahoo! Messenger 8.x CYTF] Downloading %s' % (url, ))
    log.ThugLogging.log_exploit_event(self._window.url,
                                      "Yahoo! Messenger 8.x CYTF",
                                      "Downloading",
                                      forward = False,
                                      data = {
                                                "url": url
                                             }
                                     )



# Ourgame GLWorld GLIEDown2.dll ActiveX Control Vulnerabilities

import logging

log = logging.getLogger("Thug")


def IEStartNative(self, arg0, arg1, arg2):
    if len(arg0) > 220:
        log.ThugLogging.log_exploit_event(self._window.url,
                                          "Ourgame GLWorld GLIEDown2.dll ActiveX",
                                          "IEStartNative Method Buffer Overflow")
